@@ -22,12 +22,12 @@
 #ifndef KCOMBOBOX_H
 #define KCOMBOBOX_H
 
-#include <QComboBox>
-
 #include <kcompletion.h>
-
+#include <kcompletionbase.h>
 #include <kcompletion_export.h>
 
+#include <QComboBox>
+
 class QLineEdit;
 class QMenu;
 
@@ -42,29 +42,27 @@ class QUrl;
  */
 
 /**
- * @short An enhanced combo box.
- *
- * A combined button, line-edit and a popup list widget.
- *
- * \b Detail \n
+ * @short A combo box with completion support.
  *
  * This widget inherits from QComboBox and implements the following
- * additional functionalities:  a completion object that provides both automatic
- * and manual text completion as well as text rotation features, configurable
- * key-bindings to activate these features, and a popup-menu item that can be
- * used to allow the user to change the text completion mode on the fly.
+ * additional features:
+ *   @li a completion object that provides both automatic
+ * and manual text completion as well as text rotation
+ *   @li configurable key bindings to activate these features
+ *   @li a popup menu item that can be used to allow the user to change
+ * the text completion mode on the fly.
  *
- * To support these new features KComboBox emits a few additional signals
- * such as completion( const QString& ) and textRotation( KeyBindingType ).
+ * To support these new features, KComboBox emits a few additional signals
+ * such as completion(const QString&) and textRotation(KeyBindingType).
  * The completion signal can be connected to a slot that will assist the user in
  * filling out the remaining text while the rotation signal can be used to traverse
  * through all possible matches whenever text completion results in multiple matches.
- * Additionally, a returnPressed() and a returnPressed( const QString& )
+ * Additionally, the returnPressed() and returnPressed(const QString&)
  * signals are emitted when the user presses the Enter/Return key.
  *
  * KCombobox by default creates a completion object when you invoke the
- * completionObject( bool ) member function for the first time or
- * explicitly use setCompletionObject( KCompletion*, bool ) to assign your
+ * completionObject(bool) member function for the first time or
+ * explicitly use setCompletionObject(KCompletion*, bool) to assign your
  * own completion object.  Additionally, to make this widget more functional,
  * KComboBox will by default handle text rotation and completion events
  * internally whenever a completion object is created through either one of the
@@ -76,72 +74,72 @@ class QUrl;
  * such as setEditable(false) is made.  Store the pointer at your own risk,
  * and consider using QPointer<KCompletion>.
  *
- * The default key-bindings for completion and rotation is determined from the
+ * The default key bindings for completion and rotation are determined from the
  * global settings in KStandardShortcut. These values, however, can be overridden
  * locally by invoking KCompletionBase::setKeyBinding(). The values can
- * easily be reverted back to the default setting, by simply calling
+ * easily be reverted back to the default settings by calling
  * useGlobalSettings(). An alternate method would be to default individual
- * key-bindings by usning setKeyBinding() with the default second argument.
+ * key bindings by using setKeyBinding() with the default second argument.
  *
- * A non-editable combobox only has one completion mode, @p CompletionAuto.
- * Unlike an editable combobox the CompletionAuto mode, works by matching
- * any typed key with the first letter of entries in the combobox. Please note
- * that if you call setEditable( false ) to change an editable combobox to a
- * non-editable one, the text completion object associated with the combobox will
+ * A non-editable combo box only has one completion mode, @p CompletionAuto.
+ * Unlike an editable combo box, the CompletionAuto mode works by matching
+ * any typed key with the first letter of entries in the combo box. Please note
+ * that if you call setEditable(false) to change an editable combo box to a
+ * non-editable one, the text completion object associated with the combo box will
  * no longer exist unless you created the completion object yourself and assigned
- * it to this widget or you called setAutoDeleteCompletionObject( false ). In other
+ * it to this widget or you called setAutoDeleteCompletionObject(false). In other
  * words do not do the following:
  *
  * \code
  * KComboBox* combo = new KComboBox(true, this);
  * KCompletion* comp = combo->completionObject();
- * combo->setEditable( false );
+ * combo->setEditable(false);
  * comp->clear(); // CRASH: completion object does not exist anymore.
  * \endcode
  *
  *
  * A read-only KComboBox will have the same background color as a
  * disabled KComboBox, but its foreground color will be the one used for
- * the read-write mode. This differs from QComboBox's implementation
+ * the editable mode. This differs from QComboBox's implementation
  * and is done to give visual distinction between the three different modes:
- * disabled, read-only, and read-write.
+ * disabled, read-only, and editable.
  *
  * \b Usage \n
  *
  * To enable the basic completion feature:
  *
  * \code
- * KComboBox *combo = new KComboBox( true, this );
+ * KComboBox *combo = new KComboBox(true, this);
  * KCompletion *comp = combo->completionObject();
  * // Connect to the return pressed signal - optional
  * connect(combo,SIGNAL(returnPressed(const QString&)),comp,SLOT(addItem(const QString&)));
  *
  * // Provide the to be completed strings. Note that those are separate from the combo's
  * // contents.
- * comp->insertItems( someQStringList );
+ * comp->insertItems(someQStringList);
  * \endcode
  *
  * To use your own completion object:
  *
  * \code
- * KComboBox *combo = new KComboBox( this );
+ * KComboBox *combo = new KComboBox(this);
  * KUrlCompletion *comp = new KUrlCompletion();
- * combo->setCompletionObject( comp );
+ * combo->setCompletionObject(comp);
  * // Connect to the return pressed signal - optional
  * connect(combo,SIGNAL(returnPressed(const QString&)),comp,SLOT(addItem(const QString&)));
  * \endcode
  *
  * Note that you have to either delete the allocated completion object
  * when you don't need it anymore, or call
- * setAutoDeleteCompletionObject( true );
+ * setAutoDeleteCompletionObject(true);
  *
  * Miscellaneous function calls:
  *
  * \code
  * // Tell the widget not to handle completion and rotation
- * combo->setHandleSignals( false );
+ * combo->setHandleSignals(false);
  * // Set your own completion key for manual completions.
- * combo->setKeyBinding( KCompletionBase::TextCompletion, Qt::End );
+ * combo->setKeyBinding(KCompletionBase::TextCompletion, Qt::End);
  * \endcode
  *
  * \image html kcombobox.png "KDE Combo Boxes, one non-editable, one editable with KUrlCompletion"
@@ -160,17 +158,14 @@ class KCOMPLETION_EXPORT KComboBox : public QComboBox, public KCompletionBase //
 public:
 
     /**
-    * Constructs a read-only or rather select-only combo box with a
-    * parent object and a name.
+    * Constructs a read-only (or rather select-only) combo box.
     *
     * @param parent The parent object of this widget
     */
     explicit KComboBox(QWidget *parent = 0);
 
     /**
-    * Constructs a "read-write" or "read-only" combo box depending on
-    * the value of the first argument( @p rw ) with a parent, a
-    * name.
+    * Constructs an editable or read-only combo box.
     *
     * @param rw When @p true, widget will be editable.
     * @param parent The parent object of this widget.
@@ -206,49 +201,57 @@ public:
 #endif
 
     /**
-     * Sets @p url into the edit field of the combobox. It uses
-     * QUrl::toDisplayString() so that the url is properly decoded for
+     * Sets @p url into the edit field of the combo box.
+     *
+     * It uses QUrl::toDisplayString() so that the url is properly decoded for
      * displaying.
      */
     void setEditUrl(const QUrl &url);
 
     /**
-     * Appends @p url to the combobox.
+     * Appends @p url to the combo box.
+     *
      * QUrl::toDisplayString() is used so that the url is properly decoded
      * for displaying.
      */
     void addUrl(const QUrl &url);
 
     /**
-     * Appends @p url with the icon &p icon to the combobox.
+     * Appends @p url with the @p icon to the combo box.
+     *
      * QUrl::toDisplayString() is used so that the url is properly decoded
      * for displaying.
      */
     void addUrl(const QIcon &icon,  const QUrl &url);
 
     /**
-     * Inserts @p url at position @p index into the combobox.
+     * Inserts @p url at position @p index into the combo box.
+     *
      * QUrl::toDisplayString() is used so that the url is properly decoded
      * for displaying.
      */
     void insertUrl(int index, const QUrl &url);
 
     /**
-     * Inserts @p url with the pixmap &p pixmap at position @p index into
-     * the combobox. QUrl::toDisplayString() is used so that the url is
+     * Inserts @p url with the @p icon at position @p index into
+     * the combo box.
+     *
+     * QUrl::toDisplayString() is used so that the url is
      * properly decoded for displaying.
      */
     void insertUrl(int index, const QIcon &icon, const QUrl &url);
 
     /**
      * Replaces the item at position @p index with @p url.
+     *
      * QUrl::toDisplayString() is used so that the url is properly decoded
      * for displaying.
      */
     void changeUrl(int index, const QUrl &url);
 
     /**
-     * Replaces the item at position @p index with @p url and icon @p icon.
+     * Replaces the item at position @p index with @p url and @p icon.
+     *
      * QUrl::toDisplayString() is used so that the url is properly decoded
      * for displaying.
      */
@@ -257,8 +260,8 @@ public:
     /**
     * Returns the current cursor position.
     *
-    * This method always returns a -1 if the combo-box is @em not
-    * editable (read-write).
+    * This method always returns a -1 if the combo box is @em not
+    * editable (read-only).
     *
     * @return Current cursor position.
     */
@@ -288,27 +291,29 @@ public:
     bool autoCompletion() const;
 
     /**
-    * Enables or disable the popup (context) menu.
+    * Enables or disables the popup (context) menu.
     *
-    * This method only works if this widget is editable, i.e. read-write and
+    * This method only works if this widget is editable, and
     * allows you to enable/disable the context menu. It does nothing if invoked
-    * for a none-editable combo-box.
+    * for a non-editable combo box.
     *
     * By default, the context menu is created if this widget is editable.
     * Call this function with the argument set to false to disable the popup
     * menu.
     *
     * @param showMenu If @p true, show the context menu.
-    * @deprecated use setContextMenuPolicy
+    * @deprecated since 5.0, use setContextMenuPolicy instead
     */
 #ifndef KDE_NO_DEPRECATED
     virtual KCOMPLETION_DEPRECATED void setContextMenuEnabled(bool showMenu);
 #endif
 
     /**
-     * Enables/Disables handling of URL drops. If enabled and the user
-     * drops an URL, the decoded URL will be inserted. Otherwise the default
-     * behavior of QComboBox is used, which inserts the encoded URL.
+     * Enables/Disables handling of URL drops.
+     *
+     * If enabled and the user drops an URL, the decoded URL will
+     * be inserted. Otherwise the default behavior of QComboBox is used,
+     * which inserts the encoded URL.
      *
      * @param enable If @p true, insert decoded URLs
      * @deprecated since 5.0. Use lineEdit()->installEventFilter with a LineEditUrlDropEventFilter
@@ -329,28 +334,28 @@ public:
      * If @p text is an empty string, @p false
      * is returned.
      *
-     * @return @p true if an item with the string @p text is in the combobox.
+     * @return @p true if an item with the string @p text is in the combo box.
      */
     bool contains(const QString &text) const;
 
     /**
      * By default, KComboBox recognizes Key_Return and Key_Enter
      * and emits the returnPressed() signals, but it also lets the
-     * event pass, for example causing a dialog's default-button to
+     * event pass, for example causing a dialog's default button to
      * be called.
      *
      * Call this method with @p trap equal to true to make KComboBox
      * stop these events. The signals will still be emitted of course.
      *
-     * Only affects read-writable comboboxes.
+     * Only affects editable combo boxes.
      *
      * @see setTrapReturnKey()
      */
     void setTrapReturnKey(bool trap);
 
     /**
-     * @return @p true if keyevents of Key_Return or Key_Enter will
-     * be stopped or if they will be propagated.
+     * @return @p true if key events of Key_Return or Key_Enter will
+     * be stopped; @p false if they will be propagated.
      *
      * @see setTrapReturnKey ()
      */
@@ -362,10 +367,11 @@ public:
     virtual bool eventFilter(QObject *, QEvent *);
 
     /**
-     * @returns the completion-box, that is used in completion mode
+     * @returns the completion box that is used in completion mode
      * CompletionPopup and CompletionPopupAuto.
-     * This method will create a completion-box by calling
-     * KLineEdit::completionBox, if none is there, yet.
+     *
+     * This method will create a completion box by calling
+     * KLineEdit::completionBox, if none is there yet.
      *
      * @param create Set this to false if you don't want the box to be created
      *               i.e. to test if it is available.
@@ -377,14 +383,14 @@ public:
      * Note that QComboBox::setLineEdit is not virtual in Qt4, do not
      * use a KComboBox in a QComboBox pointer.
      *
-     * NOTE: Only editable comboboxes can have a line editor. As such
-     * any attempt to assign a line-edit to a non-editable combobox will
+     * NOTE: Only editable combo boxes can have a line editor. As such
+     * any attempt to assign a line edit to a non-editable combo box will
      * simply be ignored.
      */
     virtual void setLineEdit(QLineEdit *);
 
     /**
-     * "Re-implemented" so that setEditable(true) creates a KLineEdit
+     * Re-implemented so that setEditable(true) creates a KLineEdit
      * instead of QLineEdit.
      *
      * Note that QComboBox::setEditable is not virtual, so do not
@@ -404,7 +410,7 @@ Q_SIGNALS:
     * Emitted when the user presses the Enter key.
     *
     * The argument is the current text being edited.  This signal is just like
-    * returnPressed() except it contains the current text as its argument.
+    * returnPressed() except that it contains the current text as its argument.
     *
     * Note that this signal is only emitted when the
     * widget is editable.
@@ -427,15 +433,16 @@ Q_SIGNALS:
     void substringCompletion(const QString &);
 
     /**
-     * Emitted when the text rotation key-bindings are pressed.
+     * Emitted when the text rotation key bindings are pressed.
      *
-     * The argument indicates which key-binding was pressed. In this case this
+     * The argument indicates which key binding was pressed. In this case this
      * can be either one of four values: @p PrevCompletionMatch,
-     * @p NextCompletionMatch, @p RotateUp or @p RotateDown. See
-     * KCompletionBase::setKeyBinding() for details.
+     * @p NextCompletionMatch, @p RotateUp or @p RotateDown.
      *
-     * Note that this signal is @em NOT emitted if the completion
+     * Note that this signal is @em not emitted if the completion
      * mode is set to CompletionNone.
+     *
+     * @see KCompletionBase::setKeyBinding() for details
      */
     void textRotation(KCompletionBase::KeyBindingType);
 
@@ -449,7 +456,7 @@ Q_SIGNALS:
      * Emitted before the context menu is displayed.
      *
      * The signal allows you to add your own entries into the context menu.
-     * Note that you MUST NOT store the pointer to the QPopupMenu since it is
+     * Note that you <em>must not</em> store the pointer to the QPopupMenu since it is
      * created and deleted on demand.  Otherwise, you can crash your app.
      *
      * @param p the context menu about to be displayed
@@ -463,7 +470,7 @@ public Q_SLOTS:
     * or the history list.
     *
     * Depending on the value of the argument, this function either
-    * iterates through the history list of this widget or the all
+    * iterates through the history list of this widget or all the
     * possible matches in whenever multiple matches result from a
     * text completion request.  Note that the all-possible-match
     * iteration will not work if there are no previous matches, i.e.
@@ -473,12 +480,12 @@ public Q_SLOTS:
     * For other insertion modes whatever has been typed by the user
     * when the rotation event was initiated will be lost.
     *
-    * @param type The key-binding invoked.
+    * @param type The key binding invoked.
     */
     void rotateText(KCompletionBase::KeyBindingType type);
 
     /**
-     * Sets the completed text in the line-edit appropriately.
+     * Sets the completed text in the line edit appropriately.
      *
      * This function is an implementation for
      * KCompletionBase::setCompletedText.
@@ -486,15 +493,16 @@ public Q_SLOTS:
     virtual void setCompletedText(const QString &);
 
     /**
-     * Sets @p items into the completion-box if completionMode() is
+     * Sets @p items into the completion box if completionMode() is
      * CompletionPopup. The popup will be shown immediately.
      */
     void setCompletedItems(const QStringList &items, bool autosubject = true);
 
     /**
-     * Selects the first item that matches @p item. If there is no such item,
-     * it is inserted at position @p index if @p insert is true. Otherwise,
-     * no item is selected.
+     * Selects the first item that matches @p item.
+     *
+     * If there is no such item, it is inserted at position @p index
+     * if @p insert is true. Otherwise, no item is selected.
      */
     void setCurrentItem(const QString &item, bool insert = false, int index = -1);
 
@@ -503,10 +511,10 @@ protected Q_SLOTS:
     /**
     * Completes text according to the completion mode.
     *
-    * Note: this method is @p not invoked if the completion mode is
-    * set to CompletionNone.  Also if the mode is set to @p CompletionShell
+    * Note: this method is not invoked if the completion mode is
+    * set to @p CompletionNone.  Also if the mode is set to @p CompletionShell
     * and multiple matches are found, this method will complete the
-    * text to the first match with a beep to inidicate that there are
+    * text to the first match with a beep to indicate that there are
     * more matches.  Then any successive completion key event iterates
     * through the remaining matches.  This way the rotation functionality
     * is left to iterate through the list as usual.
@@ -514,15 +522,15 @@ protected Q_SLOTS:
     virtual void makeCompletion(const QString &);
 
 protected:
-    /*
-    * This function simply sets the lineedit text and
+    /**
+    * This function sets the line edit text and
     * highlights the text appropriately if the boolean
     * value is set to true.
     *
-    * @param
-    * @param
+    * @param text The text to be set in the line edit
+    * @param marked Whether the text inserted should be highlighted
     */
-    virtual void setCompletedText(const QString & /* */, bool /*marked*/);
+    virtual void setCompletedText(const QString &text, bool marked);
 
     virtual void wheelEvent(QWheelEvent *ev);
 
